==> api-service-common-0.12.28.tgz: package/src/middleware/local_file.ts <==
/*************************************************************************
 *
 * Troven CONFIDENTIAL
 * __________________
 *
 *  (c) 2017-2020 Troven Pty Ltd
 *  All Rights Reserved.
 *
 * NOTICE:  All information contained herein is, and remains
 * the property of Troven Pty Ltd and its licensors,
 * if any.  The intellectual and technical concepts contained
 * herein are proprietary to Troven Pty Ltd
 * and its suppliers and may be covered by International and Regional Patents,
 * patents in process, and are protected by trade secret or copyright law.
 * Dissemination of this information or reproduction of this material
 * is strictly forbidden unless prior written permission is obtained
 * from Troven Pty Ltd.
 */

import { IOperation, IChassisFeature } from "api-service-core";
import * as express from "express";

/**
 * Local File
 * -------------
 * Attach an API resource to local JSON assets from file system
 *
 *  static_assets:
 *      path:  {current_folder}+"./public"/
 *
 * @type {{name: string, title: string, description: string, fn: module.exports.fn}}
 */
export default class local_file implements IChassisFeature {
    name = "api.file";
    title = "Local File";

    fn(operation: IOperation, options: any): Function {
        let folder = operation.feature.folder || options.folder || process.cwd()+"/local";

//        console.log("LOCAL FILE: %o --> %o", operation.resource, folder);

        operation.actionId = "get";
        let wildcard = operation.resource.indexOf("/*");
        if (wildcard>=0) {
            operation.resource = operation.resource.substring(0,wildcard);
        }

        operation.context.log({ code:  "api:local_file", resource: operation.resource, folder: folder});

        return express.static(folder, options);
    }

};

==> api-service-common-0.16.13.tgz: package/src/middleware/local_file.ts <==
/*************************************************************************
 *
 * Troven CONFIDENTIAL
 * __________________
 *
 *  (c) 2017-2020 Troven Pty Ltd
 *  All Rights Reserved.
 *
 * NOTICE:  All information contained herein is, and remains
 * the property of Troven Pty Ltd and its licensors,
 * if any.  The intellectual and technical concepts contained
 * herein are proprietary to Troven Pty Ltd
 * and its suppliers and may be covered by International and Regional Patents,
 * patents in process, and are protected by trade secret or copyright law.
 * Dissemination of this information or reproduction of this material
 * is strictly forbidden unless prior written permission is obtained
 * from Troven Pty Ltd.
 */

import { IOperation, IChassisFeature } from "api-service-core";
import * as express from "express";

/**
 * Local File
 * -------------
 * Attach an API resource to local JSON assets from file system
 *
 *  static_assets:
 *      path:  {current_folder}+"./public"/
 *
 * @type {{name: string, title: string, description: string, fn: module.exports.fn}}
 */
export default class local_file implements IChassisFeature {
    name = "api.file";
    title = "Local File";

    fn(operation: IOperation, options: any): Function {
        let folder = options.folder || process.cwd()+"/local";

//        console.log("LOCAL FILE: %j --> %j", operation.resource, folder);

        operation.actionId = "get";
        let wildcard = operation.resource.indexOf("/*");
        if (wildcard>=0) {
            operation.resource = operation.resource.substring(0,wildcard);
        }

        operation.context.log({ code:  "api:local_file", resource: operation.resource, folder: folder});

        return express.static(folder, options);
    }

};
